# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools.

Nesse curso é ensinado como contribuir com projetos de código aberto.

Link do curso [Python Pro] (www.python.pro.br/)

[![codecov](https://codecov.io/gh/rsa1971/libpythonpro/branch/master/graph/badge.svg)](https://codecov.io/gh/rsa1971/libpythonpro)

[![Build Status](https://travis-ci.com/rsa1971/libpythonpro.svg?branch=master)](https://travis-ci.com/rsa1971/libpythonpro)


Suportada versão 3 de Python.

Para instalar:

'''console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt'''

Para conferir qualidade de código:

'''console
flake8
'''

Tópicos a serem abordados:
1. Git
2. Virtualen
3. PIP.

